@@ -1,4 +1,4 @@
-/* $Id: DBIXS.h,v 10.11 1999/07/12 02:02:33 timbo Exp $
+/* $Id: DBIXS.h,v 10.15 2000/06/11 02:27:27 timbo Exp $
  *
  * Copyright (c) 1994, 1995, 1996, 1997, 1998, 1999  Tim Bunce  England
  *
@@ -24,19 +24,7 @@
 #endif
 
 /* Perl backwards compatibility definitions */
-#ifndef boolSV	/* added in perl5.004		*/
-#define boolSV(bool) ((bool) ? &sv_yes : &sv_no) 
-#endif
-
-#ifndef dTHR	/* added in perl5.004_50	*/
-#define dTHR typedef int _thr_DBI_dummy
-#endif
-
-#if defined(__CYGWIN__) || defined(__CYGWIN32__)
-#ifdef debug
-#undef debug
-#endif
-#endif
+#include "dbipport.h"
 
 /* DBI SQL_* type definitions */
 #include "dbi_sql.h"
@@ -362,7 +350,7 @@ typedef struct {
     U16 spare_pad;
 
     I32 debug;
-    FILE *logfp;
+    PerlIO *logfp;
 
     /* pointers to DBI functions which the DBD's will want to use	*/
     char      * (*neat_svpv)	_((SV *sv, STRLEN maxlen));
@@ -381,7 +369,8 @@ typedef struct {
 
     dbi_mutex	*mutex;
 
-    void *pad[9];
+    int         (*logmsg)	_((SV *h, imp_xxh_t *imp_xxh, char *fmt, ...));
+    void *pad[8];
 } dbistate_t;
 
 /* macros for backwards compatibility */
@@ -391,21 +380,34 @@ typedef struct {
 #define DBISTATE_PERLNAME "DBI::_dbistate"
 #define DBISTATE_ADDRSV   (perl_get_sv(DBISTATE_PERLNAME, 0x05))
 #define DBILOGFP	(DBIS->logfp)
+#ifdef IN_DBI_XS
+#define DBILOGMSG	(dbih_logmsg)
+#else
+#define DBILOGMSG	(DBIS->logmsg)
+#endif
+
 
 /* --- perl object (ActiveState) / multiplicity hooks and hoops --- */
+/* note that USE_ITHREADS implies MULTIPLICITY                      */
 #if defined(MULTIPLICITY) || defined(PERL_OBJECT) || defined(PERL_CAPI)
 
 # define DBISTATE_DECLARE
+# define DBISTATE_ASSIGN(st)
 # define DBISTATE_INIT
-static dbistate_t * get_dbistate() {
-    return ((dbistate_t*)SvIVX(DBISTATE_ADDRSV));
+static dbistate_t **get_dbistate() {
+    return ((dbistate_t**)&SvIVX(DBISTATE_ADDRSV));
 }
-# define DBIS (get_dbistate())
+# undef DBIS
+# define DBIS (*get_dbistate())
+
+/* temporary for drivers that mistakenly use 'dbis' instead of 'DBIS' */
+# define dbis (*get_dbistate())
 
 #else	/* plain and simple non perl object / multiplicity case */
 
 # define DBISTATE_DECLARE	static dbistate_t *DBIS
-# define DBISTATE_INIT_DBIS	(DBIS = (dbistate_t*)SvIV(DBISTATE_ADDRSV))
+# define DBISTATE_ASSIGN(st)	(DBIS = (st))
+# define DBISTATE_INIT_DBIS	DBISTATE_ASSIGN((dbistate_t*)SvIV(DBISTATE_ADDRSV))
 # define DBISTATE_INIT {	/* typically use in BOOT: of XS file	*/    \
     DBISTATE_INIT_DBIS;	\
     if (DBIS == NULL)	\
