@@ -1,6 +1,6 @@
-# $Id: DBD.pm,v 10.7 1999/05/06 17:29:14 timbo Exp $
+# $Id: DBD.pm,v 10.8 2000/06/11 00:06:02 timbo Exp $
 #
-# Copyright (c) 1997,1998 Jonathan Leffler, Jochen Wiedmann and Tim Bunce
+# Copyright (c) 1997-2000 Jonathan Leffler, Jochen Wiedmann and Tim Bunce
 #
 # You may distribute under the terms of either the GNU General Public
 # License or the Artistic License, as specified in the Perl README file.
@@ -15,8 +15,8 @@ DBI::DBD - DBD Driver Writer's Guide
 
 =head1 VERSION and VOLATILITY
 
-	$Revision: 10.7 $
-	$Date: 1999/05/06 17:29:14 $
+	$Revision: 10.8 $
+	$Date: 2000/06/11 00:06:02 $
 
 This document is a minimal draft which is in need of further work.
 
@@ -43,6 +43,31 @@ need to use judgement in applying the guidelines in this document.
 If in I<any> doubt at all, please do contact the dbi-dev mailing list
 (details given below) where Tim Bunce and other driver authors can help.
 
+The primary web-site for locating DBI software and information is
+
+  http://www.symbolstone.org/technology/perl/DBI
+
+There are 2 main and one auxilliary mailing lists for people working
+with DBI.  The primary lists are dbi-users@isc.org for general users
+of DBI and DBD drivers, and dbi-dev@isc.org mainly for DBD driver
+writers (don't join the dbi-dev list unless you have a good reason).
+The auxilliary list is dbi-announce@isc.org for announcing new
+releases of DBI or DBD drivers.
+
+You can join these lists by accessing the web-site
+L<http://www.isc.org/dbi-lists.html>.
+The lists are closed so you cannot send email to any of the lists
+unless you join the list first.
+
+You should also consider monitoring the comp.lang.perl.* newsgroups.
+
+=head1 BOOK
+
+The definitive book on Perl DBI is 'Programming the Perl DBI: Database
+programming with Perl' by Alligator Descartes and Tim Bunce, published
+by O'Reilly Associates, February 2000, ISBN 1-56592-699-4.  Buy it now
+if you have not already done so.
+
 =head1 REGISTERING A NEW DRIVER
 
 Before writing a new driver, it is in your interests to find out
@@ -62,26 +87,7 @@ Two of the main pages you should look at are:
 
   http://www.perl.org/CPAN/modules/by-category/07_Database_Interfaces/DBD
 
-The primary web-site for locating DBI software and information is
-
-  http://www.arcana.co.uk/technologia/perl/DBI
-
-=head2 DBI Mailing Lists
-
-There are 2 main and one auxilliary mailing lists for people working
-with DBI.  The primary lists are dbi-users@fugue.com for general users
-of DBI and DBD drivers, and dbi-dev@fugue.com mainly for DBD driver
-writers (don't join the dbi-dev list unless you have a good reason).
-The auxilliary list is dbi-announce@fugue.com for announcing new
-releases of DBI or DBD drivers.
-
-You can join these lists by accessing the web-site
-L<http://www.fugue.com/dbi>.
-If you have not got web access, you may send a request to
-dbi-request@fugue.com, but this will be handled manually when the
-people in charge find the time to deal with it.  Use the web-site.
-
-You should also consider monitoring the comp.lang.perl.* newsgroups.
+See the DBI docs for information on DBI web sites and mailing lists.
 
 =head2 Registering a new driver
 
@@ -169,6 +175,87 @@ distribution tar file that is uploaded to CPAN. It should list every
 file that you want to include in your distribution, one per line.
 
 
+=head2 lib/Bundle/DBD/Driver.pm
+
+The CPAN module provides an extremely powerful bundle mechanism that
+allows you to specify pre-requisites for your driver.
+The primary pre-requisite is Bundle::DBI; you may want or need to add
+some more.
+With the bundle set up correctly, the user can type:
+
+	perl -MCPAN -e 'install Bundle::DBD::Driver'
+
+and Perl will download, compile, test and install all the Perl modules
+needed to build your driver.
+
+A suitable skeleton for this file is shown below.
+The prerequisite modules are listed in the CONTENTS section, with the
+official name of the module followed by a dash and an informal name or
+description.
+Listing Bundle::DBI as the main pre-requisite simplifies life.
+Don't forget to list your driver.
+Note that unless the DBMS is itself a Perl module, you cannot list it
+as a pre-requisite in this file.
+You are strongly advised to keep the version of the bundle in sync
+with the version of your driver.
+You might want to add configuration management, copyright, and
+licencing information at the top.
+
+
+    package Bundle::DBD::Driver;
+
+    $VERSION = '0.01';
+
+    1;
+
+    __END__
+
+    =head1 NAME
+
+    Bundle::DBD::Driver - A bundle to install all DBD::Driver related modules
+
+    =head1 SYNOPSIS
+
+    C<perl -MCPAN -e 'install Bundle::DBD::Driver'>
+
+    =head1 CONTENTS
+
+    Bundle::DBI  - Bundle for DBI by TIMB (Tim Bunce)
+
+    DBD::Driver  - DBD::Driver by YOU (Your Name)
+
+    =head1 DESCRIPTION
+
+    This bundle includes all the modules used by the Perl Database
+    Interface (DBI) driver for Driver (DBD::Driver), assuming the
+    use of DBI version 1.13 or later, created by Tim Bunce.
+
+    If you've not previously used the CPAN module to install any
+    bundles, you will be interrogated during its setup phase.
+    But when you've done it once, it remembers what you told it.
+    You could start by running:
+
+        C<perl -MCPAN -e 'install Bundle::CPAN'>
+
+    =head1 SEE ALSO
+
+    Bundle::DBI
+
+    =head1 AUTHOR
+
+    Your Name E<lt>F<you@yourdomain.com>E<gt>
+
+    =head1 THANKS
+
+    This bundle was created by ripping off Bundle::libnet created by
+    Graham Barr E<lt>F<gbarr@ti.com>E<gt>, and radically simplified
+    with some information from Jochen Wiedmann E<lt>F<joe@ispsoft.de>E<gt>.
+    The template was then included in the DBI::DBD documentation by
+    Jonathan Leffler E<lt>F<jleffler@informix.com>E<gt>.
+
+    =cut
+
+
 =head2 Driver.pm
 
 The Driver.pm file defines the Perl module DBD::Driver for your driver.
@@ -643,7 +730,7 @@ T.B.S.
 
 =head2 CODE TO BE WRITTEN
 
-A minimal driver will typically contain 7 files plus some tests.
+A minimal driver will typically contain 9 files plus some tests.
 Assuming that your driver is called DBD::Driver, these files are:
 
 =over 4
@@ -664,6 +751,8 @@ Assuming that your driver is called DBD::Driver, these files are:
 
 =item MANIFEST
 
+=item lib/Bundle/DBD/Driver.pm
+
 =back
 
 
@@ -1612,7 +1701,7 @@ DBD::Oracle driver.
 
 =head1 AUTHORS
 
-Jonathan Leffler <johnl@informix.com>,
+Jonathan Leffler <jleffler@informix.com>,
 Jochen Wiedmann <joe@ispsoft.de>,
 and Tim Bunce.
 
@@ -1639,7 +1728,7 @@ BEGIN { if ($^O eq 'VMS') {
 
 @ISA = qw(Exporter);
 
-$VERSION = substr(q$Revision: 10.7 $, 10);
+$VERSION = substr(q$Revision: 10.8 $, 10);
 
 @EXPORT = qw(
     dbd_dbi_dir dbd_dbi_arch_dir
